slepc-3.18.0 2022-10-01
Report Typos and Errors

# SVDProblemType

Determines the type of singular value problem

### Synopsis

    typedef enum { SVD_STANDARD=1,
                   SVD_GENERALIZED,   /* GSVD */
                   SVD_HYPERBOLIC     /* HSVD */
                 } SVDProblemType;

### See Also

SVDSetProblemType(), SVDGetProblemType()

### Level

beginner

### Location

include/slepcsvd.h

### Examples

src/svd/tutorials/ex15.c.html
src/svd/tutorials/ex15f.F.html
src/svd/tutorials/ex45.c.html
src/svd/tutorials/ex48.c.html
src/svd/tutorials/ex51.c.html
src/svd/tutorials/ex52.c.html
Index of all SVD routines
Table of Contents for all manual pages
Index of all manual pages